@@ -1,15 +1,9 @@
 package MaxMind::DB::Common;
-$MaxMind::DB::Common::VERSION = '0.031003';
+
 use strict;
 use warnings;
 
-# This is a hack to let us test code that requires a specific
-# MaxMind::DB::Common version against the MaxMind-DB-Common git repo code, but
-# without actually setting the $VERSION variable.
-BEGIN {
-    $MaxMind::DB::Common::{VERSION} = \99
-        unless exists $MaxMind::DB::Common::{VERSION};
-}
+our $VERSION = '0.040000';
 
 my $separator_size;
 
@@ -27,6 +21,7 @@ use constant {
 
 use Exporter qw( import );
 
+## no critic (Variables::ProhibitPackageVars)
 our %TypeNumToName = (
     0  => 'extended',
     1  => 'pointer',
@@ -72,7 +67,7 @@ MaxMind::DB::Common - Code shared by the MaxMind DB reader and writer modules
 
 =head1 VERSION
 
-version 0.031003
+version 0.040000
 
 =head1 DESCRIPTION
 
@@ -107,9 +102,15 @@ Olaf Alders <oalders@maxmind.com>
 
 =back
 
+=head1 CONTRIBUTOR
+
+=for stopwords Greg Oschwald
+
+Greg Oschwald <goschwald@maxmind.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by MaxMind, Inc..
+This software is Copyright (c) 2015 by MaxMind, Inc..
 
 This is free software, licensed under:
 
