@@ -1,10 +1,10 @@
 package MaxMind::DB::Metadata;
-$MaxMind::DB::Metadata::VERSION = '0.031003';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
-use Math::Int128;
+our $VERSION = '0.040000';
 
 use Moo;
 use MaxMind::DB::Types qw( ArrayRefOfStr Epoch HashRefOfStr Int Str );
@@ -106,7 +106,7 @@ MaxMind::DB::Metadata - A class for metadata related to a MaxMind DB database
 
 =head1 VERSION
 
-version 0.031003
+version 0.040000
 
 =head1 SYNOPSIS
 
@@ -121,6 +121,8 @@ This class provides an API for representing the metadata of a MaxMind DB
 database. See http://maxmind.github.io/MaxMind-DB/ for the official format
 spec.
 
+=for test_synopsis my $path;
+
 =head1 API
 
 This class provides methods for each metadata attribute in a database.
@@ -180,7 +182,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by MaxMind, Inc..
+This software is Copyright (c) 2015 by MaxMind, Inc..
 
 This is free software, licensed under:
 
