@@ -1,10 +1,12 @@
 package Test::MaxMind::DB::Common::Data;
-$Test::MaxMind::DB::Common::Data::VERSION = '0.031003';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.040000';
+
 use Exporter qw( import );
-use Math::Int128 qw( uint128 );
+use Math::BigInt ();
 
 our @EXPORT_OK = qw( test_cases_for );
 
@@ -16,6 +18,7 @@ sub test_cases_for {
     return __PACKAGE__->$method(@_);
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _array {
     my @one_value = (
         ['Foo'] => [
@@ -84,22 +87,25 @@ sub _bytes {
     );
 
     my $bytes_500 = 'x' x 500;
-    push @bytes, $bytes_500 => [
+    push @bytes,
+        $bytes_500 => [
         0b10011110, 0b00000000, 0b11010111,
         map { ord($_) } split //, $bytes_500
-    ];
+        ];
 
     my $bytes_2000 = 'x' x 2000;
-    push @bytes, $bytes_2000 => [
+    push @bytes,
+        $bytes_2000 => [
         0b10011110, 0b00000110, 0b10110011,
         map { ord($_) } split //, $bytes_2000
-    ];
+        ];
 
     my $bytes_70000 = 'x' x 70000;
-    push @bytes, $bytes_70000 => [
+    push @bytes,
+        $bytes_70000 => [
         0b10011111, 0b00000000, 0b00010000, 0b01010011,
         map { ord($_) } split //, $bytes_70000
-    ];
+        ];
 
     return \@bytes;
 }
@@ -404,19 +410,19 @@ sub _pointer {
 
 sub _uint128 {
     my @uint128 = (
-        uint128(0)   => [ 0b00000000, 0b00000011 ],
-        uint128(500) => [
+        Math::BigInt->bzero()  => [ 0b00000000, 0b00000011 ],
+        Math::BigInt->new(500) => [
             0b00000010, 0b00000011,
             0b00000001, 0b11110100
         ],
-        uint128(10872) => [
+        Math::BigInt->new(10872) => [
             0b00000010, 0b00000011,
             0b00101010, 0b01111000
         ],
     );
 
     for my $power ( 1 .. 16 ) {
-        my $key = uint128(2)**( 8 * $power ) - uint128(1);
+        my $key = Math::BigInt->new(2)**( 8 * $power ) - Math::BigInt->bone();
 
         my $value = [
             $power, 0b00000011,
@@ -431,19 +437,19 @@ sub _uint128 {
 
 sub _uint64 {
     my @uint64 = (
-        uint128(0)   => [ 0b00000000, 0b00000010 ],
-        uint128(500) => [
+        Math::BigInt->bzero()  => [ 0b00000000, 0b00000010 ],
+        Math::BigInt->new(500) => [
             0b00000010, 0b00000010,
             0b00000001, 0b11110100
         ],
-        uint128(10872) => [
+        Math::BigInt->new(10872) => [
             0b00000010, 0b00000010,
             0b00101010, 0b01111000
         ],
     );
 
     for my $power ( 1 .. 8 ) {
-        my $key = uint128(2)**( 8 * $power ) - uint128(1);
+        my $key = Math::BigInt->new(2)**( 8 * $power ) - Math::BigInt->bone();
 
         my $value = [
             $power, 0b00000010,
@@ -547,22 +553,25 @@ sub _utf8_string {
     );
 
     my $string_500 = 'x' x 500;
-    push @string, $string_500 => [
+    push @string,
+        $string_500 => [
         0b01011110, 0b00000000, 0b11010111,
         map { ord($_) } split //, $string_500
-    ];
+        ];
 
     my $string_2000 = 'x' x 2000;
-    push @string, $string_2000 => [
+    push @string,
+        $string_2000 => [
         0b01011110, 0b00000110, 0b10110011,
         map { ord($_) } split //, $string_2000
-    ];
+        ];
 
     my $string_70000 = 'x' x 70000;
-    push @string, $string_70000 => [
+    push @string,
+        $string_70000 => [
         0b01011111, 0b00000000, 0b00010000, 0b01010011,
         map { ord($_) } split //, $string_70000
-    ];
+        ];
 
     return \@string;
 }
@@ -577,5 +586,6 @@ sub _boolean {
         ],
     ];
 }
+## use critic
 
 1;
